pub struct Forwarding(/* private fields */);Expand description
Trillium handler for forwarded/x-forwarded-* headers
See crate-level docs for an explanation
Implementations
Sourceimpl Forwarding
impl Forwarding
Sourcepub fn trust_ips<'a>(ips: impl IntoIterator<Item = &'a str>) -> Self
pub fn trust_ips<'a>(ips: impl IntoIterator<Item = &'a str>) -> Self
builds a Forwarding handler that trusts a list of strings that represent either specific IPs or a CIDR range.
let forwarding = Forwarding::trust_ips(["10.1.10.1"]);
let forwarding = Forwarding::trust_ips(["10.1.10.1", "192.168.0.0/16"]);Panics
Panics if any of the provided strings is neither an ip address nor a CIDR range.
Sourcepub fn trust_fn<F>(trust_predicate: F) -> Self
pub fn trust_fn<F>(trust_predicate: F) -> Self
builds a Forwarding handler that trusts a peer ip based on the provided predicate function.
let forwarding = Forwarding::trust_fn(IpAddr::is_loopback);
let forwarding = Forwarding::trust_fn(|ip| match ip {
IpAddr::V6(_) => false,
IpAddr::V4(ipv4) => ipv4.is_link_local(),
});Sourcepub fn trust_always() -> Self
pub fn trust_always() -> Self
builds a Forwarding handler that expects that all http connections
will always come from a trusted and spec-compliant reverse
proxy. This should only be used in situations in which the
application is either running inside of a vpc and the reverse
proxy ip cannot be known. Using an overbroad trust rule such as
trust_always introduces security risk to an application, as it
allows any request to forge Forwarded headers.